find_unique_artifact

Function find_unique_artifact 

fn find_unique_artifact(
    project: &Project,
    output: ProjectCompileOutput,
    code: &Bytes,
) -> Result<Option<(ArtifactId, ConfigurableContractArtifact)>>
Returns the artifact whose deployed bytecode is code.

Fails if the code matches more than one contract, since each can have a different storage layout.