same_artifact

Function same_artifact 

fn same_artifact(left: &ArtifactId, right: &ArtifactId) -> bool
Returns whether two artifact IDs identify the same contract across compiler runs.

Changing the output selection changes the build ID, and compiling fewer files can change an artifact path that was disambiguated due to a name collision. Neither can be used to match the normal compile against the targeted storage-layout compile.